Pyosmium Reference
==================

Pyosmium is a thin wrapper to the osmium library. Where possible it follows
its structure and naming scheme. This reference provides a short description
of the exported classes and interfaces. More details and background
information can be found in the osmium manual.

.. toctree::
    :maxdepth: 2

    ref_osmium
    ref_osm
    ref_io
    ref_index
    ref_geom
    ref_replication
